import turtle
from itertools import cycle

colors=cycle(['red','orange','yellow','green','blue','purple'])

def draw_circle(size,angle,shift):
    turtle.pencolor(next(colors))
    turtle.circle(size)
    turtle.right(angle)
    turtle.forward(shift)
    draw_circle(size + 5,angle + 1,shift + 1)
    
turtle.shape('turtle')
turtle.bgcolor('Thistle')
turtle.speed('fastest')
turtle.pensize(4)
draw_circle(30,0,1)
